@@ -4,9 +4,6 @@ use strict;
 use warnings;
 use DynaLoader;
 
-# Make sure debugging with Data::Dumper is more easily comparable:
-$Data::Dumper::Sortkeys = 1;
-
 # different files, but same package
 # require them here to avoid dependencies
 use URPM::Build;
@@ -14,7 +11,7 @@ use URPM::Resolve;
 use URPM::Signature;
 
 our @ISA = qw(DynaLoader);
-our $VERSION = 'v5.125';
+our $VERSION = '5.15';
 
 URPM->bootstrap($VERSION);
 
@@ -293,7 +290,7 @@ URPM - Manipulate RPM files and headers
     });
 
     # loading and parsing a synthesis file
-    my $urpm = URPM->new;
+    my $urpm = new URPM;
     $urpm->parse_synthesis("synthesis.sample.cz");
     $urpm->traverse(sub {
 	# retrieve all packages from the dependency list
@@ -353,9 +350,6 @@ Force the re-reading of the RPM configuration files.
 $urpm->{depslist} is loaded when parsing sources (synthesis, hdlists or a plain
 rpm file).
 
-Synthesis and hdlists files are generated by L<genhdlist2> or L<gendistrib> (a
-gendhlist2 wrapper handling a whole media set) from L<rpmtools> package.
-
 =over
 
 =item $urpm->parse_synthesis($file [, callback => sub {...} ])
@@ -843,11 +837,6 @@ Options are:
     update => 0 / 1 : indicates whether this is an upgrade
     excludepath => [ ... ]
 
-=item $trans->addReinstall($pkg)
-
-Adds a package to be re-installed to the transaction represented by $trans.
-$pkg is an C<URPM::Package> object.
-
 =item $trans->remove($name)
 
 Adds a package to be erased to the transaction represented by $trans.
@@ -885,7 +874,6 @@ Recognized options are:
     callback_open   => sub { ... }
     callback_trans  => sub { ... }
     callback_uninst => sub { ... }
-    callback_verify => sub { ... }
     delta => used for progress callbacks (trans, uninst, inst)
     excludedocs => 0 / 1
     force => 0 / 1
@@ -898,13 +886,13 @@ Recognized options are:
 
 They roughly correspond to command-line options to rpm(1).
 
-'callback_open' signature is (C<$data>, C<$cb_type>, C<$pkg_id>). It _must_ return a file handler for the asked package.
+'callback_open' signature is (C<$data>, C<$cb_type>, C<$pkg_id>, C<pkg_name>). It _must_ return a file handler for the asked package.
 
-'callback_close' signature is (C<$data>, C<$cb_type>, C<$pkg_id>). It is called just before URPM close the fd for the installed package.
+'callback_close' signature is (C<$data>, C<$cb_type>, C<$pkg_id>, C<pkg_name>). It is called just before URPM close the fd for the installed package.
 
 C<$cb_type> is one of 'open' or 'close'.
 
-Other Callbacks signature is callback(C<$data>, C<$cb_type>, C<$pkg_id>, C<$subtype>, C<$amout>, C<$total>)
+Other Callbacks signature is callback(C<$data>, C<$cb_type>, C<$pkg_id>, C<$subtype>, C<$amout>, C<$total>, C<pkg_name>)
 
 C<$cb_type> is one of 'elem', 'error', 'inst', 'trans' or 'uninst'. C<$subtype> can be 'start', 'progress' or 'stop'.
 For 'error', it can be 'cpio', 'script' or 'unpack'.
@@ -1055,8 +1043,6 @@ B<transaction_state>: $state object
 
 The L<URPM::Resolve> implements the resolving bits.
 
-The L<URPM::Signature> implements the pubkey bits.
-
 The L<urpm> package is a higher level module used by the urpmi command line tool,
 the rpmdrake GUI and the drakx installer.
 
